@@ -318,7 +318,7 @@ greetd_json_builder_end (PhogGreetd *self, JsonBuilder *builder, GError **error)
     g_autoptr(JsonParser) parser = json_parser_new ();
     g_autoptr(JsonGenerator) generator = json_generator_new ();
     g_autoptr(JsonNode) request_root = NULL;
-    g_autoptr(JsonNode) reply_root = NULL;
+    JsonNode *reply_root;
     g_autofree gchar *data = NULL;
     JsonObject *root_object;
     const gchar *reply_type;
